@@ -21,6 +21,7 @@
 #' @param force_x_theta_updates Defaults to 1 where theta estimation is not allowed to converge until thetas have updated for x iterations . Useful when model is not degenerate but simulated statistics do not match observed network well when algorithm stops after first x updates.
 #' @param output_directory The directory where you would like output generated by the GERGM estimation proceedure to be saved (if output_name is specified). This includes, GOF, trace, and parameter estimate plots, as well as a summary of the estimation proceedure and an .Rdata file containing the GERGM object returned by this function. May be left as NULL if the user would prefer all plots be printed to the graphics device.
 #' @param output_name The common name stem you would like to assign to all object output by the gergm function. Default value of NULL will not save any output directly to .pdf files, it will be printed to the console instead. Must be a character string or NULL. For example, if "Test" is supplied as the output_name, then 4 files will be output: "Test_GOF.pdf", "Test_Parameter_Estimates.pdf", "Test_GERGM_Object.Rdata", "Test_Estimation_Log.txt", and "Test_Trace_Plot.pdf"
+#' @param generate_plots Defaults to TRUE, if FALSE, then no diagnostic or parameter plots are generated.
 #' @return A gergm object containing parameter estimates.
 #' @export
 gergm <- function(formula,
@@ -43,7 +44,8 @@ gergm <- function(formula,
                   acceptable_fit_p_value_threshold = 0.05,
                   force_x_theta_updates = 1,
                   output_directory = NULL,
-                  output_name = NULL
+                  output_name = NULL,
+                  generate_plots = TRUE
                   ){
 
   #' This is the main function to estimate a GERGM model
@@ -231,39 +233,41 @@ gergm <- function(formula,
   # Gof_Plot(GERGM_Object)
 
   #4. output everything to the appropriate files and eturn GERGM object.
-  # only generate output if output_name is not NULL
-  if(!is.null(output_name)){
-    if(is.null(output_directory)){
-      output_directory <- getwd()
+  if(generate_plots){
+    # only generate output if output_name is not NULL
+    if(!is.null(output_name)){
+      if(is.null(output_directory)){
+        output_directory <- getwd()
+      }
+      current_directory <- getwd()
+      setwd(output_directory)
+
+      pdf(file = paste(output_name,"_GOF.pdf",sep = ""), height = 4, width = 8)
+      GOF(GERGM_Object)
+      dev.off()
+
+      pdf(file = paste(output_name,"_Parameter_Estimates.pdf",sep = ""), height = 4, width = 5)
+      Estimate_Plot(GERGM_Object)
+      dev.off()
+
+      pdf(file = paste(output_name,"_Trace_Plot.pdf",sep = ""), height = 4, width = 6)
+      Trace_Plot(GERGM_Object)
+      dev.off()
+
+      save(GERGM_Object, file = paste(output_name,"_GERGM_Object.Rdata",sep = ""))
+
+      write.table(GERGM_Object@console_output,file = paste(output_name,"_Estimation_Log.txt",sep = ""),row.names = F,col.names = F,fileEncoding = "utf8", quote = F)
+
+      setwd(current_directory)
+    }else{
+      # if we are not saving everything to a directory then just print stuff to
+      # the graphics device
+      GOF(GERGM_Object)
+      Sys.sleep(2)
+      Estimate_Plot(GERGM_Object)
+      Sys.sleep(2)
+      Trace_Plot(GERGM_Object)
     }
-    current_directory <- getwd()
-    setwd(output_directory)
-
-    pdf(file = paste(output_name,"_GOF.pdf",sep = ""), height = 4, width = 8)
-    GOF(GERGM_Object)
-    dev.off()
-
-    pdf(file = paste(output_name,"_Parameter_Estimates.pdf",sep = ""), height = 4, width = 5)
-    Estimate_Plot(GERGM_Object)
-    dev.off()
-
-    pdf(file = paste(output_name,"_Trace_Plot.pdf",sep = ""), height = 4, width = 6)
-    Trace_Plot(GERGM_Object)
-    dev.off()
-
-    save(GERGM_Object, file = paste(output_name,"_GERGM_Object.Rdata",sep = ""))
-
-    write.table(GERGM_Object@console_output,file = paste(output_name,"_Estimation_Log.txt",sep = ""),row.names = F,col.names = F,fileEncoding = "utf8", quote = F)
-
-    setwd(current_directory)
-  }else{
-    # if we are not saving everything to a directory then just print stuff to
-    # the graphics device
-    GOF(GERGM_Object)
-    Sys.sleep(2)
-    Estimate_Plot(GERGM_Object)
-    Sys.sleep(2)
-    Trace_Plot(GERGM_Object)
   }
 
   return(GERGM_Object)
